/**
 * \par Copyright (C), 2012-2016, MakeBlock
 * \class   MeEncoderMotorDriverV2
 * \brief   Driver for Encoder module.
 * @file    MeEncoderMotorDriverV2.h
 * @author  MakeBlock
 * @version V1.0.0
 * @date    2017/11/17
 * @brief   Header for MeEncoderMotorDriverV2.cpp module
 *
 * \par Copyright
 * This software is Copyright (C), 2012-2016, MakeBlock. Use is subject to license \n
 * conditions. The main licensing options available are GPL V2 or Commercial: \n
 *
 * \par Open Source Licensing GPL V2
 * This is the appropriate option if you want to share the source code of your \n
 * application with everyone you distribute it to, and you also want to give them \n
 * the right to share who uses it. If you wish to use this software under Open \n
 * Source Licensing, you must contribute all your source code to the open source \n
 * community in accordance with the GPL Version 2 when your application is \n
 * distributed. See http://www.gnu.org/copyleft/gpl.html
 *
 * \par Description
 * This file is a drive for Encoder.
 *
 * \par Method List:
 *
 * \par History:
 * <pre>
 * `<Author>`         `<Time>`        `<Version>`        `<Descr>`
 * Payton        2017/12/20     1.0.0            Build New
 * </pre>
 */

#ifndef ME_Encoder_NEW_TEST_H
#define ME_Encoder_NEW_TEST_H

#include <Arduino.h>
#include <stdbool.h>
#include <avr/interrupt.h>
#include <MeEncoderNew.h>


/**
 * Class: MeEncoderMotorDriverV2
 * \par Description
 * Declaration of Class MeEncoderMotorDriverV2
 */
class MeEncoderMotorDriverV2 : public MeEncoderNew
{
public:
/**
 * Alternate Constructor which can call your own function to map the Encoder Motor New to arduino port,
 * you can set any slot for the Encoder Motor New device. 
 * \param[in]
 *   port - RJ25 port from PORT_1 to PORT_10
 * \param[in]
 *   slot - SLOT1 or SLOT2
 */
  MeEncoderMotorDriverV2(uint8_t addr,uint8_t slot);

/**
 * Alternate Constructor which can call your own function to map the Encoder Motor New to arduino port,
 * you can set any slot for the Encoder Motor New device.
 * \param[in]
 *   slot - SLOT1 or SLOT2
 */
  MeEncoderMotorDriverV2(uint8_t slot);

/**
 * Alternate Constructor which can call your own function to map the Encoder Motor New to arduino port,
 * you should initialized slot and slaveAddress here for the Encoder Motor New device.
 * \param[in]
 *   None
 */
  MeEncoderMotorDriverV2(void);


private:
  uint8_t _mode;

};
#endif



